@@ -1,11 +1,12 @@
-=head1 Directory::Diff::Copy
-
 =head1 NAME
 
 Directory::Diff::Copy - Copy differences between two directories
 
 =head1 SYNOPSIS
 
+   use Directory::Diff::Copy 'copy_diff_only';
+   copy_diff_only ($old_dir, $new_dir, $output_dir);
+
 =cut
 
 package Directory::Diff::Copy;
@@ -14,7 +15,7 @@ require Exporter;
 @EXPORT_OK = qw/copy_diff_only/;
 use warnings;
 use strict;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use Carp;
 use File::Copy;
 use File::Path;
@@ -136,5 +137,4 @@ sub copy_diff_only
     return $data{count};
 }
 
-
 1;
